;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
; NAME:PLACECOLOR
;
; PURPOSE:permet de tracer la colorbar independammment d'un graphe
;
; CATEGORY:graph
;
; CALLING SEQUENCE:placecolor,pos
;
; INPUTS:
;	pos:vecteur de 4 elements donnant les coordonnees du coin en bas
; a gauche et de celui en haut a droite -en cm- ds lequel on veut faire la
; barre de couleur
;
; KEYWORD PARAMETERS: tous ceux de colorbar.pro.
;
; par defaut trace une barre de couleur du meme type que celle presente ds plt
; et pltz. si max, min et divisions ne sont pas stipulees alors max=sup,min=inf
; et divisions=div
;
; OUTPUTS:
;
; COMMON BLOCKS:
;	common.pro
;
; SIDE EFFECTS:
;
; RESTRICTIONS:utilisable que pour les POSTCRIPT effectues avec plein2dessin
;
; EXAMPLE:
;
; MODIFICATION HISTORY: Sebastien Masson (smasson@lodyc.jussieu.fr)
;			7/5/98
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
pro placecolor,pos,_extra = ex
@common
;------------------------------------------------------------
   xsave = !x
   ysave = !y
   psave = !p

   reinitplt, /z, /invert
   pos=1.*pos
   if key_portrait eq 1 then begin
      pos[0]=pos[0]/petitfeuille    
      pos[1]=pos[1]/grandfeuille    
      pos[2]=pos[2]/petitfeuille    
      pos[3]=pos[3]/grandfeuille    
   endif else begin
      pos[0]=pos[0]/grandfeuille    
      pos[1]=pos[1]/petitfeuille    
      pos[2]=pos[2]/grandfeuille    
      pos[3]=pos[3]/petitfeuille    
   endelse
   if keyword_set(divisions) eq 0 then divisions=colorbardiv
   if keyword_set(max) eq 0 then max=colorbarsup
   if keyword_set(min) eq 0 then min=colorbarinf
   COLORBAR, COLOR=0, DIVISIONS=divisions, DISCRET=couleur, cb_color = 0, $
    POSITION=pos, MAX=max, MIN=min, cb_charsize=!p.charsize, _extra = ex

   !x = xsave
   !y = ysave
   !p = psave
;------------------------------------------------------------
   return
end
